path_stem

Function path_stem 

pub fn path_stem(path: &str) -> String
Path(path).stem — pathlib semantics: final component (trailing slashes and . segments dropped), minus the last suffix, where a suffix exists only when the final dot is neither at index 0 nor the last char.