validate_artifact

Function validate_artifact 

pub fn validate_artifact(artifact: &Artifact) -> Vec<Issue>
Structural validation for decided validate: syntax and rule contracts do not require a repository tree and therefore fail the ordinary corpus gate even when code enforcement was not requested.