pub fn spec_for(name: &str) -> Option<&'static ArtifactSpec>Expand description
The spec for a canonical type name, or None for "unknown" / unregistered.
pub fn spec_for(name: &str) -> Option<&'static ArtifactSpec>The spec for a canonical type name, or None for "unknown" / unregistered.