pub fn load_freshness_threshold(start_dir: &str) -> i64Expand description
load_freshness_threshold(start_dir) (ADR-045): the
freshness.stale_after_days from the nearest .decided/config.yaml.
Defaults to 180 when there is no config, no freshness mapping, or the
value is not a positive int — YAML 1.1 bools are explicitly rejected
(true/false are not day counts even though bool is an int
subclass in Python).